@@ -46,7 +46,7 @@ public:
 
 class UninstallWizard : public WizardBase
 {
-	Q_OBJECT
+	TQ_OBJECT
 
 public:
 	UninstallWizard(TQWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
