@@ -65,8 +65,8 @@ void MyHidden::createService_clicked()
     if (static_cast<tork*>(this->topLevelWidget()->parentWidget())->connectedToTor()){
         HidSrvWizard wizard;
         wizard.setCaption( i18n( "Hidden Services Wizard" ));
-        connect( &wizard, SIGNAL(createService(const TQString&,const TQString&)),this->topLevelWidget()->parent(), SLOT(createService(const TQString&,const TQString& )) );
-        connect( &wizard, SIGNAL(addService(const TQString&,const TQString&,const TQString&,const TQString&,const TQString&,const TQString&)), SLOT(addService(const TQString&,const TQString&,const TQString&,const TQString&,const TQString&,const TQString&)) );
+        connect( &wizard, TQ_SIGNAL(createService(const TQString&,const TQString&)),this->topLevelWidget()->parent(), TQ_SLOT(createService(const TQString&,const TQString& )) );
+        connect( &wizard, TQ_SIGNAL(addService(const TQString&,const TQString&,const TQString&,const TQString&,const TQString&,const TQString&)), TQ_SLOT(addService(const TQString&,const TQString&,const TQString&,const TQString&,const TQString&,const TQString&)) );
         wizard.exec();
     }else{
         TQString caption = i18n("Not Connected To Tor!");
@@ -130,8 +130,8 @@ void MyHidden::startService_clicked()
                 << "-h " << servicesList->currentItem()->text(3).section(":",0,0)
                 << "-d " << servicesList->currentItem()->text(4);
 
- 	connect( thttpdproc, SIGNAL(processExited(TDEProcess *)),
- 			SLOT(thttpdprocExited(TDEProcess *)) );
+ 	connect( thttpdproc, TQ_SIGNAL(processExited(TDEProcess *)),
+ 			TQ_SLOT(thttpdprocExited(TDEProcess *)) );
 
 	thttpdproc->start(KProcIO::NotifyOnExit)    ;
 
