@@ -60,7 +60,7 @@ class streamItem;
  */
 class torkView : public torkview_base
 {
-    Q_OBJECT
+    TQ_OBJECT
 
 	enum {
 		HISTORY_SIZE = 300,	// Speed history buffer size
@@ -379,7 +379,7 @@ TQString torkView::byteFormat( double num, const char* ksufix,
 
 class streamItem : public TQObject, public TQListViewItem
 {
-Q_OBJECT
+TQ_OBJECT
 
 public:
     streamItem( DndListView *parent, const TQString &id,
@@ -512,7 +512,7 @@ double streamItem::byteSpeedTx() const {
 
 class circuitItem : public TQObject, public TQListViewItem
 {
-Q_OBJECT
+TQ_OBJECT
 
 public:
     circuitItem( DndListView *parent, const TQString &id,
