@@ -19,8 +19,10 @@
  *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
  ***************************************************************************/
 
+#include <tqstring.h>
+
 #include "tork.h"
-#include <ntqstring.h>
+
 
 typedef struct message_t {
   const char *logmessage; /**< The full keyword (case insensitive). */
